aboutsummaryrefslogtreecommitdiff
path: root/include/sqfs/io.h
diff options
context:
space:
mode:
authorDavid Oberhollenzer <david.oberhollenzer@sigma-star.at>2019-09-23 14:17:02 +0200
committerDavid Oberhollenzer <david.oberhollenzer@sigma-star.at>2019-09-23 14:17:02 +0200
commit57da296d0e31b87040510fa49eb75e950a4f0d67 (patch)
tree251332ee0c0d5bf8ce57863532c52d970841b7a0 /include/sqfs/io.h
parentbcb5a6e74ac97004acc9a4937285f001b895e0d7 (diff)
Replace user pointer in sqfs_block_t with explicit inode pointer
Signed-off-by: David Oberhollenzer <david.oberhollenzer@sigma-star.at>
Diffstat (limited to 'include/sqfs/io.h')
-rw-r--r--include/sqfs/io.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/sqfs/io.h b/include/sqfs/io.h
index bbc3da9..f1a5ef0 100644
--- a/include/sqfs/io.h
+++ b/include/sqfs/io.h
@@ -179,15 +179,15 @@ SQFS_API sqfs_file_t *sqfs_get_stdin_file(uint64_t size);
* @param file A pointer to a file implementation.
* @param offset A byte offset into the file.
* @param size The number of bytes to read, starting at the given offset.
* @param user A user pointer to set for the block.
* @param flags The flags to store in the newly created block.
* @param out Returns a pointer to a block on success.
*
* @return Zero on success, an @ref E_SQFS_ERROR identifier on failure.
*/
SQFS_API int sqfs_file_create_block(sqfs_file_t *file, uint64_t offset,
- size_t size, void *user, uint32_t flags,
- sqfs_block_t **out);
+ size_t size, sqfs_inode_generic_t *inode,
+ uint32_t flags, sqfs_block_t **out);
/**
* @brief Read a chunk from a condensed version of a sparse file and turn it
@@ -205,7 +205,7 @@ SQFS_API int sqfs_file_create_block(sqfs_file_t *file, uint64_t offset,
* @param file A pointer to a file implementation.
* @param offset A byte offset into the file.
* @param size The number of bytes to read, starting at the given offset.
* @param user A user pointer to set for the block.
* @param flags The flags to store in the newly created block.
* @param map Describes the data regions of the original sparse file.
* @param out Returns a pointer to a block on success.
@@ -213,7 +213,8 @@ SQFS_API int sqfs_file_create_block(sqfs_file_t *file, uint64_t offset,
* @return Zero on success, an @ref E_SQFS_ERROR identifier on failure.
*/
SQFS_API int sqfs_file_create_block_dense(sqfs_file_t *file, uint64_t offset,
- size_t size, void *user,
+ size_t size,
+ sqfs_inode_generic_t *inode,
uint32_t flags,
const sqfs_sparse_map_t *map,
sqfs_block_t **out);
@@ -179,15 +179,15 @@ SQFS_API sqfs_file_t *sqfs_get_stdin_file(uint64_t size);
* @param offset A byte offset into the file.
* @param size The number of bytes to read, starting at the given offset.
- * @param user A user pointer to set for the block.
+ * @param inode The inode pointer to set for the block.
* @param flags The flags to store in the newly created block.
* @param out Returns a pointer to a block on success.
@@ -205,7 +205,7 @@ SQFS_API int sqfs_file_create_block(sqfs_file_t *file, uint64_t offset,
* @param offset A byte offset into the file.
* @param size The number of bytes to read, starting at the given offset.
- * @param user A user pointer to set for the block.
+ * @param inode The inode pointer to set for the block.
* @param flags The flags to store in the newly created block.
* @param map Describes the data regions of the original sparse file.